@@ -6,7 +6,7 @@
 #define LTTNG_TRACE_RCU_H
 
 #include <probes/lttng-tracepoint-event.h>
-#include <linux/version.h>
+#include <lttng-kernel-version.h>
 
 /*
  * Tracepoint for start/end markers used for utilization calculations.
@@ -21,11 +21,11 @@
  */
 LTTNG_TRACEPOINT_EVENT(rcu_utilization,
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 	TP_PROTO(const char *s),
-#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0)) */
+#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0)) */
 	TP_PROTO(char *s),
-#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0)) */
+#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0)) */
 
 	TP_ARGS(s),
 
@@ -37,7 +37,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_utilization,
 #ifdef CONFIG_RCU_TRACE
 
 #if defined(CONFIG_TREE_RCU) \
-	|| (LINUX_VERSION_CODE >= KERNEL_VERSION(3,19,0) \
+	|| (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,19,0) \
 		&& defined(CONFIG_PREEMPT_RCU)) \
 	|| defined(CONFIG_TREE_PREEMPT_RCU)
 
@@ -50,7 +50,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_utilization,
  * and "cpuofl", respectively), and a CPU being kicked for being too
  * long in dyntick-idle mode ("kick").
  */
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,19,0) || \
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,19,0) || \
 	LTTNG_RHEL_KERNEL_RANGE(4,18,0,80,0,0, 4,19,0,0,0,0))
 LTTNG_TRACEPOINT_EVENT(rcu_grace_period,
 
@@ -64,7 +64,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_grace_period,
 		ctf_string(gpevent, gpevent)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 LTTNG_TRACEPOINT_EVENT(rcu_grace_period,
 
 	TP_PROTO(const char *rcuname, unsigned long gpnum, const char *gpevent),
@@ -99,7 +99,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_grace_period,
  * rcu_node structure, and the mask of CPUs that will be waited for.
  * All but the type of RCU are extracted from the rcu_node structure.
  */
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,19,0) || \
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,19,0) || \
 	LTTNG_RHEL_KERNEL_RANGE(4,18,0,80,0,0, 4,19,0,0,0,0))
 LTTNG_TRACEPOINT_EVENT(rcu_grace_period_init,
 
@@ -117,7 +117,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_grace_period_init,
 		ctf_integer(unsigned long, qsmask, qsmask)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 LTTNG_TRACEPOINT_EVENT(rcu_grace_period_init,
 
 	TP_PROTO(const char *rcuname, unsigned long gpnum, u8 level,
@@ -159,7 +159,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_grace_period_init,
  * include SRCU), the grace-period number that the task is blocking
  * (the current or the next), and the task's PID.
  */
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,19,0) || \
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,19,0) || \
 	LTTNG_RHEL_KERNEL_RANGE(4,18,0,80,0,0, 4,19,0,0,0,0))
 LTTNG_TRACEPOINT_EVENT(rcu_preempt_task,
 
@@ -173,7 +173,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_preempt_task,
 		ctf_integer(int, pid, pid)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 LTTNG_TRACEPOINT_EVENT(rcu_preempt_task,
 
 	TP_PROTO(const char *rcuname, int pid, unsigned long gpnum),
@@ -206,7 +206,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_preempt_task,
  * read-side critical section exiting that critical section.  Track the
  * type of RCU (which one day might include SRCU) and the task's PID.
  */
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,19,0) || \
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,19,0) || \
 	LTTNG_RHEL_KERNEL_RANGE(4,18,0,80,0,0, 4,19,0,0,0,0))
 LTTNG_TRACEPOINT_EVENT(rcu_unlock_preempted_task,
 
@@ -220,7 +220,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_unlock_preempted_task,
 		ctf_integer(int, pid, pid)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 LTTNG_TRACEPOINT_EVENT(rcu_unlock_preempted_task,
 
 	TP_PROTO(const char *rcuname, unsigned long gpnum, int pid),
@@ -256,7 +256,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_unlock_preempted_task,
  * whether there are any blocked tasks blocking the current grace period.
  * All but the type of RCU are extracted from the rcu_node structure.
  */
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,19,0) || \
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,19,0) || \
 	LTTNG_RHEL_KERNEL_RANGE(4,18,0,80,0,0, 4,19,0,0,0,0))
 LTTNG_TRACEPOINT_EVENT(rcu_quiescent_state_report,
 
@@ -277,7 +277,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_quiescent_state_report,
 		ctf_integer(u8, gp_tasks, gp_tasks)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 LTTNG_TRACEPOINT_EVENT(rcu_quiescent_state_report,
 
 	TP_PROTO(const char *rcuname, unsigned long gpnum,
@@ -327,7 +327,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_quiescent_state_report,
  * or "kick" when kicking a CPU that has been in dyntick-idle mode for
  * too long.
  */
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,19,0) || \
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,19,0) || \
 	LTTNG_RHEL_KERNEL_RANGE(4,18,0,80,0,0, 4,19,0,0,0,0))
 LTTNG_TRACEPOINT_EVENT(rcu_fqs,
 
@@ -342,7 +342,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_fqs,
 		ctf_string(qsevent, qsevent)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 LTTNG_TRACEPOINT_EVENT(rcu_fqs,
 
 	TP_PROTO(const char *rcuname, unsigned long gpnum, int cpu, const char *qsevent),
@@ -374,7 +374,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_fqs,
 
 #endif	/*
 	 * #if defined(CONFIG_TREE_RCU)
-	 *	|| (LINUX_VERSION_CODE >= KERNEL_VERSION(3,19,0)
+	 *	|| (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,19,0)
 	 *		&& defined(CONFIG_PREEMPT_RCU))
 	 *	|| defined(CONFIG_TREE_PREEMPT_RCU)
 	 */
@@ -392,9 +392,10 @@ LTTNG_TRACEPOINT_EVENT(rcu_fqs,
  * events use the upper bits of each number, while interrupt-related
  * events use the lower bits.
  */
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,6,0))	\
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,6,0))	\
 	|| LTTNG_KERNEL_RANGE(5,5,6, 5,6,0)		\
-	|| LTTNG_KERNEL_RANGE(5,4,22, 5,5,0)
+	|| LTTNG_KERNEL_RANGE(5,4,22, 5,5,0)		\
+	|| LTTNG_UBUNTU_KERNEL_RANGE(5,0,21,46, 5,1,0,0)
 LTTNG_TRACEPOINT_EVENT(rcu_dyntick,
 
 	TP_PROTO(const char *polarity, long oldnesting, long newnesting, int dynticks),
@@ -409,7 +410,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_dyntick,
 	)
 )
 
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,16,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,16,0))
 LTTNG_TRACEPOINT_EVENT(rcu_dyntick,
 
 	TP_PROTO(const char *polarity, long oldnesting, long newnesting, atomic_t dynticks),
@@ -424,7 +425,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_dyntick,
 	)
 )
 
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 LTTNG_TRACEPOINT_EVENT(rcu_dyntick,
 
 	TP_PROTO(const char *polarity, long long oldnesting, long long newnesting),
@@ -437,7 +438,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_dyntick,
 		ctf_integer(long long, newnesting, newnesting)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 LTTNG_TRACEPOINT_EVENT(rcu_dyntick,
 
 	TP_PROTO(char *polarity, long long oldnesting, long long newnesting),
@@ -464,7 +465,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_dyntick,
 #endif
 
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 /*
  * Tracepoint for RCU preparation for idle, the goal being to get RCU
  * processing done so that the current CPU can shut off its scheduling
@@ -489,11 +490,11 @@ LTTNG_TRACEPOINT_EVENT(rcu_dyntick,
  */
 LTTNG_TRACEPOINT_EVENT(rcu_prep_idle,
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 	TP_PROTO(const char *reason),
-#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0)) */
+#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0)) */
 	TP_PROTO(char *reason),
-#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0)) */
+#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0)) */
 
 	TP_ARGS(reason),
 
@@ -510,7 +511,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_prep_idle,
  * number of lazy callbacks queued, and the fourth element is the
  * total number of callbacks queued.
  */
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,6,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,6,0))
 LTTNG_TRACEPOINT_EVENT(rcu_callback,
 
 	TP_PROTO(const char *rcuname, struct rcu_head *rhp, long qlen),
@@ -524,7 +525,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_callback,
 		ctf_integer(long, qlen, qlen)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 LTTNG_TRACEPOINT_EVENT(rcu_callback,
 
 	TP_PROTO(const char *rcuname, struct rcu_head *rhp, long qlen_lazy,
@@ -540,7 +541,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_callback,
 		ctf_integer(long, qlen, qlen)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,4,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,4,0))
 LTTNG_TRACEPOINT_EVENT(rcu_callback,
 
 	TP_PROTO(char *rcuname, struct rcu_head *rhp, long qlen_lazy,
@@ -581,7 +582,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_callback,
  * the fourth argument is the number of lazy callbacks queued, and the
  * fifth argument is the total number of callbacks queued.
  */
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,6,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,6,0))
 LTTNG_TRACEPOINT_EVENT(rcu_kfree_callback,
 
 	TP_PROTO(const char *rcuname, struct rcu_head *rhp, unsigned long offset,
@@ -596,7 +597,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_kfree_callback,
 		ctf_integer(long, qlen, qlen)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 LTTNG_TRACEPOINT_EVENT(rcu_kfree_callback,
 
 	TP_PROTO(const char *rcuname, struct rcu_head *rhp, unsigned long offset,
@@ -612,7 +613,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_kfree_callback,
 		ctf_integer(long, qlen, qlen)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,4,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,4,0))
 LTTNG_TRACEPOINT_EVENT(rcu_kfree_callback,
 
 	TP_PROTO(char *rcuname, struct rcu_head *rhp, unsigned long offset,
@@ -652,7 +653,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_kfree_callback,
  * the total number of callbacks queued, and the fourth argument is
  * the current RCU-callback batch limit.
  */
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,6,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,6,0))
 LTTNG_TRACEPOINT_EVENT(rcu_batch_start,
 
 	TP_PROTO(const char *rcuname, long qlen, long blimit),
@@ -665,7 +666,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_batch_start,
 		ctf_integer(long, blimit, blimit)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 LTTNG_TRACEPOINT_EVENT(rcu_batch_start,
 
 	TP_PROTO(const char *rcuname, long qlen_lazy, long qlen, long blimit),
@@ -679,7 +680,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_batch_start,
 		ctf_integer(long, blimit, blimit)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,9,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,9,0))
 LTTNG_TRACEPOINT_EVENT(rcu_batch_start,
 
 	TP_PROTO(char *rcuname, long qlen_lazy, long qlen, long blimit),
@@ -693,7 +694,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_batch_start,
 		ctf_integer(long, blimit, blimit)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,4,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,4,0))
 LTTNG_TRACEPOINT_EVENT(rcu_batch_start,
 
 	TP_PROTO(char *rcuname, long qlen_lazy, long qlen, int blimit),
@@ -729,11 +730,11 @@ LTTNG_TRACEPOINT_EVENT(rcu_batch_start,
  */
 LTTNG_TRACEPOINT_EVENT(rcu_invoke_callback,
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 	TP_PROTO(const char *rcuname, struct rcu_head *rhp),
-#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0)) */
+#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0)) */
 	TP_PROTO(char *rcuname, struct rcu_head *rhp),
-#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0)) */
+#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0)) */
 
 	TP_ARGS(rcuname, rhp),
 
@@ -753,11 +754,11 @@ LTTNG_TRACEPOINT_EVENT(rcu_invoke_callback,
  */
 LTTNG_TRACEPOINT_EVENT(rcu_invoke_kfree_callback,
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 	TP_PROTO(const char *rcuname, struct rcu_head *rhp, unsigned long offset),
-#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0)) */
+#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0)) */
 	TP_PROTO(char *rcuname, struct rcu_head *rhp, unsigned long offset),
-#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0)) */
+#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0)) */
 
 	TP_ARGS(rcuname, rhp, offset),
 
@@ -781,17 +782,17 @@ LTTNG_TRACEPOINT_EVENT(rcu_invoke_kfree_callback,
  */
 LTTNG_TRACEPOINT_EVENT(rcu_batch_end,
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,13,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,13,0))
 	TP_PROTO(const char *rcuname, int callbacks_invoked,
 		 char cb, char nr, char iit, char risk),
 
 	TP_ARGS(rcuname, callbacks_invoked, cb, nr, iit, risk),
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 	TP_PROTO(const char *rcuname, int callbacks_invoked,
 		 bool cb, bool nr, bool iit, bool risk),
 
 	TP_ARGS(rcuname, callbacks_invoked, cb, nr, iit, risk),
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 	TP_PROTO(char *rcuname, int callbacks_invoked,
 		 bool cb, bool nr, bool iit, bool risk),
 
@@ -805,12 +806,12 @@ LTTNG_TRACEPOINT_EVENT(rcu_batch_end,
 	TP_FIELDS(
 		ctf_string(rcuname, rcuname)
 		ctf_integer(int, callbacks_invoked, callbacks_invoked)
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,13,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,13,0))
 		ctf_integer(char, cb, cb)
 		ctf_integer(char, nr, nr)
 		ctf_integer(char, iit, iit)
 		ctf_integer(char, risk, risk)
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 		ctf_integer(bool, cb, cb)
 		ctf_integer(bool, nr, nr)
 		ctf_integer(bool, iit, iit)
@@ -819,7 +820,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_batch_end,
 	)
 )
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 /*
  * Tracepoint for rcutorture readers.  The first argument is the name
  * of the RCU flavor from rcutorture's viewpoint and the second argument
@@ -827,12 +828,12 @@ LTTNG_TRACEPOINT_EVENT(rcu_batch_end,
  */
 LTTNG_TRACEPOINT_EVENT(rcu_torture_read,
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 	TP_PROTO(const char *rcutorturename, struct rcu_head *rhp,
 		 unsigned long secs, unsigned long c_old, unsigned long c),
 
 	TP_ARGS(rcutorturename, rhp, secs, c_old, c),
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,9,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,9,0))
 	TP_PROTO(char *rcutorturename, struct rcu_head *rhp,
 		 unsigned long secs, unsigned long c_old, unsigned long c),
 
@@ -846,7 +847,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_torture_read,
 	TP_FIELDS(
 		ctf_string(rcutorturename, rcutorturename)
 		ctf_integer_hex(struct rcu_head *, rhp, rhp)
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,9,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,9,0))
 		ctf_integer(unsigned long, secs, secs)
 		ctf_integer(unsigned long, c_old, c_old)
 		ctf_integer(unsigned long, c, c)
@@ -855,7 +856,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_torture_read,
 )
 #endif
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,6,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,6,0))
 /*
  * Tracepoint for _rcu_barrier() execution.  The string "s" describes
  * the _rcu_barrier phase:
@@ -875,11 +876,11 @@ LTTNG_TRACEPOINT_EVENT(rcu_torture_read,
  */
 LTTNG_TRACEPOINT_EVENT(rcu_barrier,
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0))
 	TP_PROTO(const char *rcuname, const char *s, int cpu, int cnt, unsigned long done),
-#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0)) */
+#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0)) */
 	TP_PROTO(char *rcuname, char *s, int cpu, int cnt, unsigned long done),
-#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,12,0)) */
+#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,12,0)) */
 
 	TP_ARGS(rcuname, s, cpu, cnt, done),
 
@@ -895,7 +896,7 @@ LTTNG_TRACEPOINT_EVENT(rcu_barrier,
 
 #else /* #ifdef CONFIG_RCU_TRACE */
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,19,0) || \
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,19,0) || \
 	LTTNG_RHEL_KERNEL_RANGE(4,18,0,80,0,0, 4,19,0,0,0,0))
 #define trace_rcu_grace_period(rcuname, gp_seq, gpevent) do { } while (0)
 #define trace_rcu_grace_period_init(rcuname, gp_seq, level, grplo, grphi, \
@@ -918,17 +919,17 @@ LTTNG_TRACEPOINT_EVENT(rcu_barrier,
 #define trace_rcu_fqs(rcuname, gpnum, cpu, qsevent) do { } while (0)
 #endif
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,16,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,16,0))
 #define trace_rcu_dyntick(polarity, oldnesting, newnesting, dyntick) do { } while (0)
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 #define trace_rcu_dyntick(polarity, oldnesting, newnesting) do { } while (0)
 #else
 #define trace_rcu_dyntick(polarity) do { } while (0)
 #endif
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 #define trace_rcu_prep_idle(reason) do { } while (0)
 #endif
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,4,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,4,0))
 #define trace_rcu_callback(rcuname, rhp, qlen_lazy, qlen) do { } while (0)
 #define trace_rcu_kfree_callback(rcuname, rhp, offset, qlen_lazy, qlen) \
 	do { } while (0)
@@ -941,19 +942,19 @@ LTTNG_TRACEPOINT_EVENT(rcu_barrier,
 #endif
 #define trace_rcu_invoke_callback(rcuname, rhp) do { } while (0)
 #define trace_rcu_invoke_kfree_callback(rcuname, rhp, offset) do { } while (0)
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 #define trace_rcu_batch_end(rcuname, callbacks_invoked, cb, nr, iit, risk) \
 	do { } while (0)
 #else
 #define trace_rcu_batch_end(rcuname, callbacks_invoked) do { } while (0)
 #endif
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,9,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,9,0))
 #define trace_rcu_torture_read(rcutorturename, rhp, secs, c_old, c) \
 	do { } while (0)
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 #define trace_rcu_torture_read(rcutorturename, rhp) do { } while (0)
 #endif
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,6,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,6,0))
 #define trace_rcu_barrier(name, s, cpu, cnt, done) do { } while (0)
 #endif
 #endif /* #else #ifdef CONFIG_RCU_TRACE */
