@@ -9,11 +9,30 @@
 #include <linux/tracepoint.h>
 #include <linux/backing-dev.h>
 #include <linux/writeback.h>
-#include <linux/version.h>
+#include <lttng-kernel-version.h>
 
 #ifndef _TRACE_WRITEBACK_DEF_
 #define _TRACE_WRITEBACK_DEF_
 
+/*
+ * Use the GPL-exported bdi_dev_name introduced in kernel 5.7. Do not use
+ * static inline bdi_dev_name in prior kernels because it uses the bdi_unknown_name
+ * symbol which is not exported to GPL modules.
+ */
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,7,0))
+static inline const char *lttng_bdi_dev_name(struct backing_dev_info *bdi)
+{
+	return bdi_dev_name(bdi);
+}
+#else
+static inline const char *lttng_bdi_dev_name(struct backing_dev_info *bdi)
+{
+	if (!bdi || !bdi->dev)
+		return "(unknown)";
+	return dev_name(bdi->dev);
+}
+#endif
+
 /*
  * Vanilla kernels before 4.0 do not implement inode_to_bdi
  * RHEL kernels before 3.10.0-327.10.1 do not implement inode_to_bdi
@@ -22,7 +41,7 @@
  *  commit a212b105b07d75b48b1a166378282e8a77fbf53d which inlines
  *  inode_to_bdi but not sb_is_blkdev_sb making it unusable by modules.
  */
-#if (LINUX_VERSION_CODE < KERNEL_VERSION(4,0,0))
+#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(4,0,0))
 static inline struct backing_dev_info *lttng_inode_to_bdi(struct inode *inode)
 {
 	struct super_block *sb;
@@ -42,11 +61,11 @@ static inline struct backing_dev_info *lttng_inode_to_bdi(struct inode *inode)
 {
 	return inode_to_bdi(inode);
 }
-#endif /* #if (LINUX_VERSION_CODE < KERNEL_VERSION(4,0,0)) */
+#endif /* #if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(4,0,0)) */
 
 #endif
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,9,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,9,0))
 #define show_inode_state(state)					\
 	__print_flags(state, "|",				\
 		{I_DIRTY_SYNC,		"I_DIRTY_SYNC"},	\
@@ -60,7 +79,7 @@ static inline struct backing_dev_info *lttng_inode_to_bdi(struct inode *inode)
 		{I_DIRTY_TIME,		"I_DIRTY_TIME"},	\
 		{I_REFERENCED,		"I_REFERENCED"}		\
 	)
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,0,0))
 #define show_inode_state(state)					\
 	__print_flags(state, "|",				\
 		{I_DIRTY_SYNC,		"I_DIRTY_SYNC"},	\
@@ -75,7 +94,7 @@ static inline struct backing_dev_info *lttng_inode_to_bdi(struct inode *inode)
 		{I_DIRTY_TIME_EXPIRED,	"I_DIRTY_TIME_EXPIRED"}, \
 		{I_REFERENCED,		"I_REFERENCED"}		\
 	)
-#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0)) */
+#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,0,0)) */
 #define show_inode_state(state)					\
 	__print_flags(state, "|",				\
 		{I_DIRTY_SYNC,		"I_DIRTY_SYNC"},	\
@@ -88,16 +107,15 @@ static inline struct backing_dev_info *lttng_inode_to_bdi(struct inode *inode)
 		{I_SYNC,		"I_SYNC"},		\
 		{I_REFERENCED,		"I_REFERENCED"}		\
 	)
-#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0)) */
+#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,0,0)) */
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,0,0))
 
 LTTNG_TRACEPOINT_EVENT(writeback_dirty_page,
 	TP_PROTO(struct page *page, struct address_space *mapping),
 	TP_ARGS(page, mapping),
 	TP_FIELDS(
-		ctf_array_text(char, name,
-			mapping ? dev_name(lttng_inode_to_bdi(mapping->host)->dev) : "(unknown)", 32)
+		ctf_string(name, lttng_bdi_dev_name(mapping ? lttng_inode_to_bdi(mapping->host) : NULL))
 		ctf_integer(unsigned long, ino, mapping ? mapping->host->i_ino : 0)
 		ctf_integer(pgoff_t, index, page->index)
 	)
@@ -108,9 +126,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_dirty_inode_template,
 	TP_ARGS(inode, flags),
 	TP_FIELDS(
 		/* may be called for files on pseudo FSes w/ unregistered bdi */
-		ctf_array_text(char, name,
-			lttng_inode_to_bdi(inode)->dev ?
-				dev_name(lttng_inode_to_bdi(inode)->dev) : "(unknown)", 32)
+		ctf_string(name, lttng_bdi_dev_name(lttng_inode_to_bdi(inode)))
 		ctf_integer(unsigned long, ino, inode->i_ino)
 		ctf_integer(unsigned long, state, inode->i_state)
 		ctf_integer(unsigned long, flags, flags)
@@ -128,8 +144,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_write_inode_template,
 	TP_PROTO(struct inode *inode, struct writeback_control *wbc),
 	TP_ARGS(inode, wbc),
 	TP_FIELDS(
-		ctf_array_text(char, name,
-			dev_name(lttng_inode_to_bdi(inode)->dev), 32)
+		ctf_string(name, lttng_bdi_dev_name(lttng_inode_to_bdi(inode)))
 		ctf_integer(unsigned long, ino, inode->i_ino)
 		ctf_integer(int, sync_mode, wbc->sync_mode)
 	)
@@ -142,14 +157,13 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_write_inode_template, name, \
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WRITE_INODE(writeback_write_inode_start)
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WRITE_INODE(writeback_write_inode)
 
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,9,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,9,0))
 
 LTTNG_TRACEPOINT_EVENT(writeback_dirty_page,
 	TP_PROTO(struct page *page, struct address_space *mapping),
 	TP_ARGS(page, mapping),
 	TP_FIELDS(
-		ctf_array_text(char, name,
-			mapping ? dev_name(mapping->backing_dev_info->dev) : "(unknown)", 32)
+		ctf_string(name, lttng_bdi_dev_name(mapping ? mapping->backing_dev_info : NULL))
 		ctf_integer(unsigned long, ino, mapping ? mapping->host->i_ino : 0)
 		ctf_integer(pgoff_t, index, page->index)
 	)
@@ -160,10 +174,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_dirty_inode_template,
 	TP_ARGS(inode, flags),
 	TP_FIELDS(
 		/* may be called for files on pseudo FSes w/ unregistered bdi */
-		ctf_array_text(char, name,
-			inode->i_mapping->backing_dev_info->dev ?
-				dev_name(inode->i_mapping->backing_dev_info->dev)
-				: "(unknown)", 32)
+		ctf_string(name, lttng_bdi_dev_name(inode->i_mapping->backing_dev_info))
 		ctf_integer(unsigned long, ino, inode->i_ino)
 		ctf_integer(unsigned long, flags, flags)
 	)
@@ -179,8 +190,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_write_inode_template,
 	TP_PROTO(struct inode *inode, struct writeback_control *wbc),
 	TP_ARGS(inode, wbc),
 	TP_FIELDS(
-		ctf_array_text(char, name,
-			dev_name(inode->i_mapping->backing_dev_info->dev), 32)
+		ctf_string(name, lttng_bdi_dev_name(inode->i_mapping->backing_dev_info))
 		ctf_integer(unsigned long, ino, inode->i_ino)
 		ctf_integer(int, sync_mode, wbc->sync_mode)
 	)
@@ -193,64 +203,50 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_write_inode_template, name, \
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WRITE_INODE(writeback_write_inode_start)
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WRITE_INODE(writeback_write_inode)
 
-#endif /* (LINUX_VERSION_CODE >= KERNEL_VERSION(3,9,0)) */
+#endif /* (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,9,0)) */
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0))
 
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_work_class,
 	TP_PROTO(struct bdi_writeback *wb, struct wb_writeback_work *work),
 	TP_ARGS(wb, work),
 	TP_FIELDS(
-		ctf_array_text(char, name, wb->bdi->dev ? dev_name(wb->bdi->dev) :
-				"(unknown)", 32)
+		ctf_string(name, lttng_bdi_dev_name(wb->bdi))
 	)
 )
 
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0))
+#else
 
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_work_class,
 	TP_PROTO(struct backing_dev_info *bdi, struct wb_writeback_work *work),
 	TP_ARGS(bdi, work),
 	TP_FIELDS(
-		ctf_array_text(char, name, bdi->dev ? dev_name(bdi->dev) :
-				"(unknown)", 32)
+		ctf_string(name, lttng_bdi_dev_name(bdi))
 	)
 )
 
-#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0)) */
+#endif /* #else if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
 
-LTTNG_TRACEPOINT_EVENT_CLASS(writeback_work_class,
-	TP_PROTO(struct backing_dev_info *bdi, struct wb_writeback_work *work),
-	TP_ARGS(bdi, work),
-	TP_FIELDS(
-		ctf_array_text(char, name,
-			dev_name(bdi->dev ? bdi->dev :
-				default_backing_dev_info.dev), 32)
-	)
-)
-
-#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,0,0)) */
-
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0))
 
 #define LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(name) \
 LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_work_class, name, \
 	TP_PROTO(struct bdi_writeback *wb, struct wb_writeback_work *work), \
 	TP_ARGS(wb, work))
 
-#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
+#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
 
 #define LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(name) \
 LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_work_class, name, \
 	TP_PROTO(struct backing_dev_info *bdi, struct wb_writeback_work *work), \
 	TP_ARGS(bdi, work))
 
-#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
+#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
 
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(writeback_nothread)
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(writeback_queue)
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(writeback_exec)
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,1,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,1,0))
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(writeback_start)
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(writeback_written)
 LTTNG_TRACEPOINT_EVENT_WRITEBACK_WORK_INSTANCE(writeback_wait)
@@ -264,14 +260,13 @@ LTTNG_TRACEPOINT_EVENT(writeback_pages_written,
 	)
 )
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0))
 
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_class,
 	TP_PROTO(struct bdi_writeback *wb),
 	TP_ARGS(wb),
 	TP_FIELDS(
-		ctf_array_text(char, name,
-			dev_name(wb->bdi->dev), 32)
+		ctf_string(name, lttng_bdi_dev_name(wb->bdi))
 	)
 )
 
@@ -290,19 +285,17 @@ LTTNG_TRACEPOINT_EVENT(writeback_bdi_register,
 	TP_PROTO(struct backing_dev_info *bdi),
 	TP_ARGS(bdi),
 	TP_FIELDS(
-		ctf_array_text(char, name,
-			dev_name(bdi->dev), 32)
+		ctf_string(name, lttng_bdi_dev_name(bdi))
 	)
 )
 
-#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
+#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
 
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_class,
 	TP_PROTO(struct backing_dev_info *bdi),
 	TP_ARGS(bdi),
 	TP_FIELDS(
-		ctf_array_text(char, name,
-			dev_name(bdi->dev), 32)
+		ctf_string(name, lttng_bdi_dev_name(bdi))
 	)
 )
 
@@ -319,7 +312,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(writeback_class, name, map, \
 
 DEFINE_WRITEBACK_EVENT(writeback_bdi_register)
 
-#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
+#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
 
 DEFINE_WRITEBACK_EVENT(writeback_nowork)
 DEFINE_WRITEBACK_EVENT(writeback_wake_background)
@@ -341,7 +334,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_written,
 	TP_ARGS(bdi, written),
 
 	TP_FIELDS(
-		ctf_array_text(char, name, dev_name(bdi->dev), 32)
+		ctf_string(name, lttng_bdi_dev_name(bdi))
 		ctf_integer(int, written, written)
 	)
 )
@@ -351,7 +344,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_wbc_class,
 	TP_PROTO(struct writeback_control *wbc, struct backing_dev_info *bdi),
 	TP_ARGS(wbc, bdi),
 	TP_FIELDS(
-		ctf_array_text(char, name, dev_name(bdi->dev), 32)
+		ctf_string(name, lttng_bdi_dev_name(bdi))
 		ctf_integer(long, nr_to_write, wbc->nr_to_write)
 		ctf_integer(long, pages_skipped, wbc->pages_skipped)
 		ctf_integer(int, sync_mode, wbc->sync_mode)
@@ -359,7 +352,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_wbc_class,
 		ctf_integer(int, for_background, wbc->for_background)
 		ctf_integer(int, for_reclaim, wbc->for_reclaim)
 		ctf_integer(int, range_cyclic, wbc->range_cyclic)
-#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,1,0))
+#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,1,0))
 		ctf_integer(int, more_io, wbc->more_io)
 		ctf_integer(unsigned long, older_than_this,
 			wbc->older_than_this ? *wbc->older_than_this : 0)
@@ -374,7 +367,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_wbc_class,
 LTTNG_TRACEPOINT_EVENT_INSTANCE_MAP(writeback_wbc_class, name, map, \
 	TP_PROTO(struct writeback_control *wbc, struct backing_dev_info *bdi), \
 	TP_ARGS(wbc, bdi))
-#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,1,0))
+#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,1,0))
 LTTNG_TRACEPOINT_EVENT_WBC_INSTANCE(wbc_writeback_start, writeback_wbc_writeback_start)
 LTTNG_TRACEPOINT_EVENT_WBC_INSTANCE(wbc_writeback_written, writeback_wbc_writeback_written)
 LTTNG_TRACEPOINT_EVENT_WBC_INSTANCE(wbc_writeback_wait, writeback_wbc_writeback_wait)
@@ -384,7 +377,7 @@ LTTNG_TRACEPOINT_EVENT_WBC_INSTANCE(wbc_balance_dirty_wait, writeback_wbc_balanc
 #endif
 LTTNG_TRACEPOINT_EVENT_WBC_INSTANCE(wbc_writepage, writeback_wbc_writepage)
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,9,0) || \
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,9,0) || \
 	LTTNG_KERNEL_RANGE(5,8,6, 5,9,0) || \
 	LTTNG_KERNEL_RANGE(5,4,62, 5,5,0) || \
 	LTTNG_KERNEL_RANGE(4,19,143, 4,20,0) || \
@@ -399,30 +392,30 @@ LTTNG_TRACEPOINT_EVENT(writeback_queue_io,
 		 int moved),
 	TP_ARGS(wb, work, dirtied_before, moved),
 	TP_FIELDS(
-		ctf_array_text(char, name, dev_name(wb->bdi->dev), 32)
+		ctf_string(name, lttng_bdi_dev_name(wb->bdi))
 		ctf_integer(unsigned long, older, dirtied_before)
 		ctf_integer(int, moved, moved)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,2,0))
 LTTNG_TRACEPOINT_EVENT(writeback_queue_io,
 	TP_PROTO(struct bdi_writeback *wb,
 		 struct wb_writeback_work *work,
 		 int moved),
 	TP_ARGS(wb, work, moved),
 	TP_FIELDS(
-		ctf_array_text(char, name, dev_name(wb->bdi->dev), 32)
+		ctf_string(name, lttng_bdi_dev_name(wb->bdi))
 		ctf_integer(int, moved, moved)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,1,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,1,0))
 LTTNG_TRACEPOINT_EVENT(writeback_queue_io,
 	TP_PROTO(struct bdi_writeback *wb,
 		 unsigned long *older_than_this,
 		 int moved),
 	TP_ARGS(wb, older_than_this, moved),
 	TP_FIELDS(
-		ctf_array_text(char, name, dev_name(wb->bdi->dev), 32)
+		ctf_string(name, lttng_bdi_dev_name(wb->bdi))
 		ctf_integer(unsigned long, older,
 			older_than_this ? *older_than_this : 0)
 		ctf_integer(long, age,
@@ -434,7 +427,7 @@ LTTNG_TRACEPOINT_EVENT(writeback_queue_io,
 )
 #endif
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(5,8,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,8,0))
 LTTNG_TRACEPOINT_EVENT_MAP(global_dirty_state,
 
 	writeback_global_dirty_state,
@@ -457,7 +450,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(global_dirty_state,
 		ctf_integer(unsigned long, dirty_limit, global_dirty_limit)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,14,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,14,0))
 LTTNG_TRACEPOINT_EVENT_MAP(global_dirty_state,
 
 	writeback_global_dirty_state,
@@ -481,7 +474,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(global_dirty_state,
 		ctf_integer(unsigned long, dirty_limit, global_dirty_limit)
 	)
 )
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(3,1,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,1,0))
 LTTNG_TRACEPOINT_EVENT_MAP(global_dirty_state,
 
 	writeback_global_dirty_state,
@@ -507,11 +500,11 @@ LTTNG_TRACEPOINT_EVENT_MAP(global_dirty_state,
 )
 #endif
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,2,0))
 
 #define KBps(x)			((x) << (PAGE_SHIFT - 10))
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0))
 
 LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 
@@ -524,7 +517,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 	TP_ARGS(wb, dirty_rate, task_ratelimit),
 
 	TP_FIELDS(
-		ctf_array_text(char, bdi, dev_name(wb->bdi->dev), 32)
+		ctf_string(bdi, lttng_bdi_dev_name(wb->bdi))
 		ctf_integer(unsigned long, write_bw, KBps(wb->bdi->wb.write_bandwidth))
 		ctf_integer(unsigned long, avg_write_bw, KBps(wb->bdi->wb.avg_write_bandwidth))
 		ctf_integer(unsigned long, dirty_rate, KBps(dirty_rate))
@@ -535,7 +528,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 	)
 )
 
-#elif (LINUX_VERSION_CODE >= KERNEL_VERSION(4,2,0))
+#elif (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,2,0))
 
 LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 
@@ -548,7 +541,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 	TP_ARGS(bdi, dirty_rate, task_ratelimit),
 
 	TP_FIELDS(
-		ctf_array_text(char, bdi, dev_name(bdi->dev), 32)
+		ctf_string(bdi, lttng_bdi_dev_name(bdi))
 		ctf_integer(unsigned long, write_bw, KBps(bdi->wb.write_bandwidth))
 		ctf_integer(unsigned long, avg_write_bw, KBps(bdi->wb.avg_write_bandwidth))
 		ctf_integer(unsigned long, dirty_rate, KBps(dirty_rate))
@@ -559,7 +552,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 	)
 )
 
-#else /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,2,0)) */
+#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,2,0)) */
 
 LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 
@@ -572,7 +565,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 	TP_ARGS(bdi, dirty_rate, task_ratelimit),
 
 	TP_FIELDS(
-		ctf_array_text(char, bdi, dev_name(bdi->dev), 32)
+		ctf_string(bdi, lttng_bdi_dev_name(bdi))
 		ctf_integer(unsigned long, write_bw, KBps(bdi->write_bandwidth))
 		ctf_integer(unsigned long, avg_write_bw, KBps(bdi->avg_write_bandwidth))
 		ctf_integer(unsigned long, dirty_rate, KBps(dirty_rate))
@@ -583,9 +576,9 @@ LTTNG_TRACEPOINT_EVENT_MAP(bdi_dirty_ratelimit,
 	)
 )
 
-#endif /* #else #if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,2,0)) */
+#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,2,0)) */
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0))
 
 LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 
@@ -610,7 +603,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 	),
 
 	TP_FIELDS(
-		ctf_array_text(char, bdi, dev_name(wb->bdi->dev), 32)
+		ctf_string(bdi, lttng_bdi_dev_name(wb->bdi))
 		ctf_integer(unsigned long, limit, global_dirty_limit)
 		ctf_integer(unsigned long, setpoint,
 			(global_dirty_limit + (thresh + bg_thresh) / 2) / 2)
@@ -637,7 +630,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 	)
 )
 
-#else /* #if LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
+#else /* #if LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
 
 LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 
@@ -652,7 +645,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 		 unsigned long dirty_ratelimit,
 		 unsigned long task_ratelimit,
 		 unsigned long dirtied,
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 		 unsigned long period,
 #endif
 		 long pause,
@@ -660,7 +653,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 
 	TP_ARGS(bdi, thresh, bg_thresh, dirty, bdi_thresh, bdi_dirty,
 		dirty_ratelimit, task_ratelimit,
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 		dirtied, period, pause, start_time
 #else
 		dirtied, pause, start_time
@@ -668,7 +661,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 	),
 
 	TP_FIELDS(
-		ctf_array_text(char, bdi, dev_name(bdi->dev), 32)
+		ctf_string(bdi, lttng_bdi_dev_name(bdi))
 		ctf_integer(unsigned long, limit, global_dirty_limit)
 		ctf_integer(unsigned long, setpoint,
 			(global_dirty_limit + (thresh + bg_thresh) / 2) / 2)
@@ -687,7 +680,7 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 		ctf_integer(unsigned long, paused,
 			(jiffies - start_time) * 1000 / HZ)
 		ctf_integer(long, pause, pause * 1000 / HZ)
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,3,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,3,0))
 		ctf_integer(unsigned long, period,
 			period * 1000 / HZ)
 		ctf_integer(long, think,
@@ -696,19 +689,18 @@ LTTNG_TRACEPOINT_EVENT_MAP(balance_dirty_pages,
 #endif
 	)
 )
-#endif /* #else #if LINUX_VERSION_CODE >= KERNEL_VERSION(4,3,0)) */
+#endif /* #else #if LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(4,3,0)) */
 
-#endif /* #if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,2,0)) */
+#endif /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,2,0)) */
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,5,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,5,0))
 LTTNG_TRACEPOINT_EVENT(writeback_sb_inodes_requeue,
 
 	TP_PROTO(struct inode *inode),
 	TP_ARGS(inode),
 
 	TP_FIELDS(
-		ctf_array_text(char, name,
-			dev_name(lttng_inode_to_bdi(inode)->dev), 32)
+		ctf_string(name, lttng_bdi_dev_name(lttng_inode_to_bdi(inode)))
 		ctf_integer(unsigned long, ino, inode->i_ino)
 		ctf_integer(unsigned long, state, inode->i_state)
 		ctf_integer(unsigned long, dirtied_when, inode->dirtied_when)
@@ -742,7 +734,7 @@ LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_congest_waited_template, writeback_wai
 	TP_ARGS(usec_timeout, usec_delayed)
 )
 
-#if (LINUX_VERSION_CODE >= KERNEL_VERSION(3,1,0))
+#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(3,1,0))
 LTTNG_TRACEPOINT_EVENT_CLASS(writeback_single_inode_template,
 
 	TP_PROTO(struct inode *inode,
@@ -753,8 +745,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_single_inode_template,
 	TP_ARGS(inode, wbc, nr_to_write),
 
 	TP_FIELDS(
-		ctf_array_text(char, name,
-			dev_name(lttng_inode_to_bdi(inode)->dev), 32)
+		ctf_string(name, lttng_bdi_dev_name(lttng_inode_to_bdi(inode)))
 		ctf_integer(unsigned long, ino, inode->i_ino)
 		ctf_integer(unsigned long, state, inode->i_state)
 		ctf_integer(unsigned long, dirtied_when, inode->dirtied_when)
@@ -766,7 +757,7 @@ LTTNG_TRACEPOINT_EVENT_CLASS(writeback_single_inode_template,
 	)
 )
 
-#if (LINUX_VERSION_CODE < KERNEL_VERSION(3,5,0))
+#if (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,5,0))
 LTTNG_TRACEPOINT_EVENT_INSTANCE(writeback_single_inode_template, writeback_single_inode_requeue,
 	TP_PROTO(struct inode *inode,
 		struct writeback_control *wbc,
