@@ -2,7 +2,7 @@
 
 #else	/* CREATE_SYSCALL_TABLE */
 
-#define OVERRIDE_TABLE_32_sys_clone
-TRACE_SYSCALL_TABLE(sys_clone, sys_clone, 4120, 0)
+#define OVERRIDE_TABLE_32_clone
+TRACE_SYSCALL_TABLE(clone, clone, 4120, 0)
 
 #endif /* CREATE_SYSCALL_TABLE */
