@@ -8,14 +8,6 @@
 #ifndef _LTTNG_BUG_H
 #define _LTTNG_BUG_H
 
-#include <lttng-kernel-version.h>
-
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,38))
-#define LTTNG_BUILD_BUG_ON(cond) BUILD_BUG_ON(cond)
-#else
-#define LTTNG_BUILD_BUG_ON(cond) MAYBE_BUILD_BUG_ON(cond)
-#endif
-
 /**
  * BUILD_RUNTIME_BUG_ON - check condition at build (if constant) or runtime
  * @condition: the condition which should be false.
@@ -28,7 +20,7 @@
 #define BUILD_RUNTIME_BUG_ON(condition)				\
 	do {							\
 		if (__builtin_constant_p(condition))		\
-			LTTNG_BUILD_BUG_ON(condition);		\
+			BUILD_BUG_ON(condition);		\
 		else						\
 			BUG_ON(condition);			\
 	} while (0)
