@@ -22,7 +22,7 @@ LTTNG_STACK_FRAME_NON_STANDARD(lttng_filter_interpret_bytecode);
  * to handle user-space read.
  */
 static
-char get_char(const struct estack_entry *reg, size_t offset)
+char get_char(struct estack_entry *reg, size_t offset)
 {
 	if (unlikely(offset >= reg->u.s.seq_len))
 		return '\0';
@@ -593,39 +593,6 @@ end:
 	return ret;
 }
 
-#ifdef DEBUG
-
-#define DBG_USER_STR_CUTOFF 32
-
-/*
- * In debug mode, print user string (truncated, if necessary).
- */
-static inline
-void dbg_load_ref_user_str_printk(const struct estack_entry *user_str_reg)
-{
-	size_t pos = 0;
-	char last_char;
-	char user_str[DBG_USER_STR_CUTOFF];
-
-	pagefault_disable();
-	do {
-		last_char = get_char(user_str_reg, pos);
-		user_str[pos] = last_char;
-		pos++;
-	} while (last_char != '\0' && pos < sizeof(user_str));
-	pagefault_enable();
-
-	user_str[sizeof(user_str) - 1] = '\0';
-	dbg_printk("load field ref user string: '%s%s'\n", user_str,
-		last_char != '\0' ? "[...]" : "");
-}
-#else
-static inline
-void dbg_load_ref_user_str_printk(const struct estack_entry *user_str_reg)
-{
-}
-#endif
-
 /*
  * Return 0 (discard), or raise the 0x1 flag (log event).
  * Currently, other flags are kept for future extensions and have no
@@ -1346,7 +1313,7 @@ uint64_t lttng_filter_interpret_bytecode(void *filter_data,
 			estack_push(stack, top, ax, bx);
 			estack_ax(stack, top)->u.s.user_str =
 				*(const char * const *) &filter_stack_data[ref->offset];
-			if (unlikely(!estack_ax(stack, top)->u.s.user_str)) {
+			if (unlikely(!estack_ax(stack, top)->u.s.str)) {
 				dbg_printk("Filter warning: loading a NULL string.\n");
 				ret = -EINVAL;
 				goto end;
@@ -1355,7 +1322,7 @@ uint64_t lttng_filter_interpret_bytecode(void *filter_data,
 			estack_ax(stack, top)->u.s.literal_type =
 				ESTACK_STRING_LITERAL_TYPE_NONE;
 			estack_ax(stack, top)->u.s.user = 1;
-			dbg_load_ref_user_str_printk(estack_ax(stack, top));
+			dbg_printk("ref load string %s\n", estack_ax(stack, top)->u.s.str);
 			next_pc += sizeof(struct load_op) + sizeof(struct field_ref);
 			PO;
 		}
@@ -1373,7 +1340,7 @@ uint64_t lttng_filter_interpret_bytecode(void *filter_data,
 			estack_ax(stack, top)->u.s.user_str =
 				*(const char **) (&filter_stack_data[ref->offset
 								+ sizeof(unsigned long)]);
-			if (unlikely(!estack_ax(stack, top)->u.s.user_str)) {
+			if (unlikely(!estack_ax(stack, top)->u.s.str)) {
 				dbg_printk("Filter warning: loading a NULL sequence.\n");
 				ret = -EINVAL;
 				goto end;
