@@ -11,6 +11,7 @@
 #define _LTTNG_KERNEL_VERSION_H
 
 #include <linux/version.h>
+#include <generated/utsrelease.h>
 
 /*
  * The following defines are extracted from the toplevel Linux Makefile and
@@ -58,12 +59,6 @@
 
 #endif
 
-#if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,33))
-#include <generated/utsrelease.h>
-#else /* #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,33)) */
-#include <linux/utsrelease.h>
-#endif /* #else #if (LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(2,6,33)) */
-
 /*
  * This macro checks if the kernel version is between the two specified
  * versions (lower limit inclusive, upper limit exclusive).
