@@ -1132,11 +1132,11 @@ static void __event_probe__##_name(void *__data, _proto)		      \
 									      \
 	if (!_TP_SESSION_CHECK(session, __session))			      \
 		return;							      \
-	if (unlikely(!READ_ONCE(__session->active)))			      \
+	if (unlikely(!LTTNG_READ_ONCE(__session->active)))		      \
 		return;							      \
-	if (unlikely(!READ_ONCE(__chan->enabled)))			      \
+	if (unlikely(!LTTNG_READ_ONCE(__chan->enabled)))		      \
 		return;							      \
-	if (unlikely(!READ_ONCE(__event->enabled)))			      \
+	if (unlikely(!LTTNG_READ_ONCE(__event->enabled)))		      \
 		return;							      \
 	__lf = lttng_rcu_dereference(__session->pid_tracker.p);		      \
 	if (__lf && likely(!lttng_id_tracker_lookup(__lf, current->tgid)))    \
@@ -1225,11 +1225,11 @@ static void __event_probe__##_name(void *__data)			      \
 									      \
 	if (!_TP_SESSION_CHECK(session, __session))			      \
 		return;							      \
-	if (unlikely(!READ_ONCE(__session->active)))			      \
+	if (unlikely(!LTTNG_READ_ONCE(__session->active)))		      \
 		return;							      \
-	if (unlikely(!READ_ONCE(__chan->enabled)))			      \
+	if (unlikely(!LTTNG_READ_ONCE(__chan->enabled)))		      \
 		return;							      \
-	if (unlikely(!READ_ONCE(__event->enabled)))			      \
+	if (unlikely(!LTTNG_READ_ONCE(__event->enabled)))		      \
 		return;							      \
 	__lf = lttng_rcu_dereference(__session->pid_tracker.p);		      \
 	if (__lf && likely(!lttng_id_tracker_lookup(__lf, current->tgid)))    \
