@@ -4,15 +4,17 @@
  *
  * wrapper around irq_to_desc. Using KALLSYMS to get its address when
  * available, else we need to have a kernel that exports this function to GPL
- * modules. This export was added to the 3.4 kernels.
+ * modules. This export was added to the 3.4 kernels and removed in 5.11.
  *
  * Copyright (C) 2011-2012 Mathieu Desnoyers <mathieu.desnoyers@efficios.com>
  */
 
 #include <lttng-kernel-version.h>
+#include <linux/module.h>
 
-#if (defined(CONFIG_KALLSYMS) \
-	&& (LINUX_VERSION_CODE < KERNEL_VERSION(3,4,0)))
+#if (defined(CONFIG_KALLSYMS) && \
+	((LTTNG_LINUX_VERSION_CODE >= LTTNG_KERNEL_VERSION(5,11,0)) || \
+	 (LTTNG_LINUX_VERSION_CODE < LTTNG_KERNEL_VERSION(3,4,0))))
 
 #include <linux/kallsyms.h>
 #include <linux/interrupt.h>
